# How-to

This page contains a collection of how-to guides for the project.

- [**Command line interface**](command_line/_command_line.md): Learn how to use the Gentropy CLI.
- [**tutorials**](tutorials/_tutorials.md): Learn how to use the Gentropy Python package.

For additional information please visit [https://community.opentargets.org/](https://community.opentargets.org/)
